# XOne_Magic

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Amr Elmenyawy(Mr.Torwada) Egypt (c) 2022

## Examples of How To Use (Buggy Alpha Version)


```python
from XMagXics import Xsms

number = input('Enter Target Number : ')
text = input('Enter Message : ')

Spam = Xsms.spam(number,text)
print(spam)
```